@@ -43,7 +43,7 @@ $EXPORT_TAGS{ all } = [@EXPORT_OK];
 our $DIE_ON_ERROR = 0;
 our $PROMOTE_N32 = 1;
 
-our $VERSION = '3.024';
+our $VERSION = '3.025';
 
 sub IP {
     return Net::IPAddress::Util->new($_[0]);
@@ -193,12 +193,10 @@ sub ipv6 {
     if ($self->is_ipv4()) {
         return '::ffff:'.$self->ipv4();
     }
-    my $rv = $self->ipv6_expanded();
-    $rv =~ s/(?::)(0+:)+/::/;
-    $rv =~ s/^0+//;
-    $rv =~ s/:0+([^0])/:$1/g;
-    $rv =~ s/:0+$/:/;
-    $rv =~ s/^:/::/;
+    my $iv = $self->ipv6_expanded();
+    my $rv = join(':', map { (my $x = $_) =~ s/^0+//; $x ||= '0'; $x } split ':', $iv);
+    $rv =~ s/[^[:xdigit:]]0(:0)+/::/;
+    $rv =~ s/::+/::/g;
     return $rv;
 }
 
